Learn R Programming

picante (version 1.8.4)

comdist: Calculates inter-community mean pairwise distance

Description

Calculates MPD (mean pairwise distance) separating taxa in two communities, a measure of phylogenetic beta diversity

Usage

comdist(comm, dis, abundance.weighted = FALSE)

Value

Distance object of MPD values separating each pair of communities.

Arguments

comm

Community data matrix

dis

Interspecific distance matrix

abundance.weighted

Should mean pairwise distances separating species in two communities be weighted by species abundances? (default = FALSE)

Author

Steven Kembel <steve.kembel@gmail.com>

Details

This function calculates a measure of phylogenetic beta diversity: the expected phylogenetic distance separating two individuals or taxa drawn randomly from different communities.

References

C.O. Webb, D.D. Ackerly, and S.W. Kembel. 2008. Phylocom: software for the analysis of phylogenetic community structure and trait evolution. Bioinformatics 18:2098-2100.

See Also

mpd, ses.mpd

Examples

Run this code
data(phylocom)
comdist(phylocom$sample, cophenetic(phylocom$phylo), abundance.weighted=TRUE)

Run the code above in your browser using DataLab