Learn R Programming

picante (version 1.8.4)

mntd: Mean nearest taxon distance

Description

Calculates MNTD (mean nearest taxon distance) for taxa in a community

Usage

mntd(samp, dis, abundance.weighted=FALSE)

Value

Vector of MNTD values for each community.

Arguments

samp

Community data matrix

dis

Interspecific distance matrix

abundance.weighted

Should mean nearest taxon distances for each species be weighted by species abundance? (default = FALSE)

Author

Steven Kembel <steve.kembel@gmail.com>

Details

This metric has also been referred to as MNND (mean nearest neighbour distance), and the function was named mnnd in picante versions < 0.7.

References

Webb, C., D. Ackerly, M. McPeek, and M. Donoghue. 2002. Phylogenies and community ecology. Annual Review of Ecology and Systematics 33:475-505.

See Also

ses.mntd

Examples

Run this code
data(phylocom)
mntd(phylocom$sample, cophenetic(phylocom$phylo), abundance.weighted=TRUE)

Run the code above in your browser using DataLab