phylocom: Phylocom default data

phylocomR Documentation

Phylocom default data

Description

Phylogeny, community and trait data from the Phylocom 4.0 distribution

Usage

data(phylocom)

Format

A list with three elements:

phylo

Phylogenetic tree (an object of class phylo)

sample

Community data (a data.frame with samples in rows and species in columns

traits

Trait data (a data.frame with species in rows and traits in columns

Webb, C.O., Ackerly, D.D., and Kembel, S.W. 2008. Phylocom: software for the analysis of phylogenetic community structure and trait evolution. Version 4.0.1. http://www.phylodiversity.net/phylocom/.


picante documentation built on Aug. 23, 2026, 5:08 p.m.