prune.sample: Prune tree to match community data or trait data
Description
Prune a phylogenetic tree to include only species present in a community data set or with non-missing trait data
Usage
prune.sample(samp, phylo)
prune.missing(x, phylo)
Value
Returns a pruned phylo object
Arguments
- phylo
phylo object
- samp
Community data matrix
- x
Vector of trait data
Author
Steven Kembel <steve.kembel@gmail.com>