Reads a Phylocom sample file and converts to a community data matrix
Usage
readsample(filename = "")
Value
Community data matrix
Arguments
filename
Phylocom sample file path
Author
Steven Kembel <skembel> and Cam Webb <cwebb@oeb.harvard.edu>
References
Webb, C.O., Ackerly, D.D., and Kembel, S.W. 2008. Phylocom: software for the analysis of phylogenetic community structure and trait evolution. Version 4.0.1. http://www.phylodiversity.net/phylocom/.