writesample: Write a Phylocom community sample file

writesampleR Documentation

Write a Phylocom community sample file

Description

Write a community data matrix to a Phylocom community sample file

Usage

writesample(community, filename = "")

Arguments

community

Community data matrix

filename

Filename path

Author(s)

Steven Kembel <steve.kembel@gmail.com> and Cam Webb <cwebb@oeb.harvard.edu>

References

Webb, C.O., Ackerly, D.D., and Kembel, S.W. 2008. Phylocom: software for the analysis of phylogenetic community structure and trait evolution. Version 4.0.1. http://www.phylodiversity.net/phylocom/.


picante documentation built on Aug. 23, 2026, 5:08 p.m.