Learn R Programming

picante (version 1.8.4)

matrix2sample: Convert community data matrix to Phylocom sample

Description

Converts a community data matrix to a Phylocom database-format community sample

Usage

matrix2sample(z)

Value

Phylocom database-format community sample

Arguments

z

Community data matrix

Author

Steven Kembel <steve.kembel@gmail.com> and Cam Webb <cwebb@oeb.harvard.edu>

References

Webb, C.O., Ackerly, D.D., and Kembel, S.W. 2008. Phylocom: software for the analysis of phylogenetic community structure and trait evolution. Version 4.0.1. http://www.phylodiversity.net/phylocom/.

Examples

Run this code
data(phylocom)
matrix2sample(phylocom$sample)

Run the code above in your browser using DataLab