powered by
Converts a community data matrix to a Phylocom database-format community sample
matrix2sample(z)
Phylocom database-format community sample
Community data matrix
Steven Kembel <[email protected]> and Cam Webb <[email protected]>
Webb, C.O., Ackerly, D.D., and Kembel, S.W. 2008. Phylocom: software for the analysis of phylogenetic community structure and trait evolution. Version 4.0.1. http://www.phylodiversity.net/phylocom/.
data(phylocom) matrix2sample(phylocom$sample)
Run the code above in your browser using DataLab