pcd(comm, tree, PSVmncd=NULL, PSVpool=NULL, reps=10^4)PSVmncdcomm, but the species pool can be defined under
any hypothesis of community assembly either by manipulating the code or inputting a user defined PSVmncd and PSVpool.psv, phylosor, unifracdata(phylocom)
pcd(phylocom$sample, phylocom$phylo)Run the code above in your browser using DataLab