| phylocom | R Documentation |
Phylogeny, community and trait data from the Phylocom 4.0 distribution
data(phylocom)
A list with three elements:
Phylogenetic tree (an object of class phylo)
Community data (a data.frame with samples in rows and species in columns
Trait data (a data.frame with species in rows and traits in columns
Webb, C.O., Ackerly, D.D., and Kembel, S.W. 2008. Phylocom: software for the analysis of phylogenetic community structure and trait evolution. Version 4.0.1. http://www.phylodiversity.net/phylocom/.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.