Learn R Programming

picante (version 1.8.4)

phylocom: Phylocom default data

Description

Phylogeny, community and trait data from the Phylocom 4.0 distribution

Usage

data(phylocom)

Arguments

Format

A list with three elements:

phylo

Phylogenetic tree (an object of class phylo)

sample

Community data (a data.frame with samples in rows and species in columns

traits

Trait data (a data.frame with species in rows and traits in columns