powered by
Phylogeny, community and trait data from the Phylocom 4.0 distribution
data(phylocom)
A list with three elements:
Phylogenetic tree (an object of class phylo)
Community data (a data.frame with samples in rows and species in columns
Trait data (a data.frame with species in rows and traits in columns