Randomize sample/community data matrices to create null distributions of given metrics
phylostruct(samp, tree, env=NULL, metric=c("psv","psr","pse","psc","sppregs"),
null.model=c("frequency", "richness","independentswap","trialswap"),
runs=100, it=1000, alpha=0.05, fam="binomial")metric used
permutation used
number of permutations
number of swaps if applicable
observed mean value of a particular metric or the three observed correlations from sppregs
mean(s) of the null distribution(s)
quantiles of the null distribution(s) to compare to obs; determined by alpha
if obs less than (alpha/2), phylo.structure="underdispersed"; if obs greater than (1-alpha/2), phylo.structure="overdispersed"; otherwise phylo.structure="random" and NULL if metric="sppregs"
null values of the distribution(s)
community data matrix, species as columns, communities as rows
phylo tree object or a phylogenetic covariance matrix
environmental data matrix
if metric="psv", "psr", "pse", or "psc" compares the observed mean of the respective metric to a null distribution at a given alpha; if metric="sppregs" compares the three correlations produced by sppregs to null distributions
permutation procedure used to create the null distribution, see randomizeMatrix
the number of permutations to create the distribution, a rule of thumb is (number of communities)/alpha
the number of swaps for the independent and trial-swap null models, see randomizeMatrix
probability value to compare the observed mean/correlations to a null distribution
as in sppregs
Matthew Helmus mrhelmus@gmail.com
The function creates null distributions for the psd set of metrics and for the correlations of sppregs from observed community data sets.
Helmus M.R., Bland T.J., Williams C.K. & Ives A.R. (2007a) Phylogenetic measures of biodiversity. American Naturalist, 169, E68-E83
Helmus M.R., Savage K., Diebel M.W., Maxted J.T. & Ives A.R. (2007b) Separating the determinants of phylogenetic community structure. Ecology Letters, 10, 917-925
Gotelli N.J. (2000) Null model analysis of species co-occurrence patterns. Ecology, 81, 2606-2621
psd ,sppregs, randomizeMatrix