powered by
Reads a Phylocom sample file and converts to a community data matrix
readsample(filename = "")
Community data matrix
Phylocom sample file path
Steven Kembel <skembel> and Cam Webb <[email protected]>
Webb, C.O., Ackerly, D.D., and Kembel, S.W. 2008. Phylocom: software for the analysis of phylogenetic community structure and trait evolution. Version 4.0.1. http://www.phylodiversity.net/phylocom/.